\name{getSignals}
\alias{getSignals}
\title{\code{getSignals} extracts the signals per block for each target}
\usage{
  getSignals(signalData, normalizerData = NULL,
    fg = "F700.Median", bg = "B700.Median",
    norm = "F800.Median", badFlags = -100)
}
\arguments{
  \item{signalData}{data.frame, usually produced by
  \code{read.gpr}, with columns "Block" (the block
  numbers), "Column" (the slide columns), "Row" (the slide
  rows), "ID" (the target ID, usually the capture-antibody
  names) and columns for the signal foreground and local
  background.}

  \item{normalizerData}{data.frame (see signalData).
  Defaults to \code{NULL}. In this case, the signal is not
  normalized.}

  \item{fg}{character, the column name of the signal
  foreground to be used. Defaults to "F700.Median".}

  \item{bg}{character, the column name of the local signal
  background. Defaults to "B700.Median".}

  \item{norm}{character, the column name of the foreground
  signal in the normalizer data.frame used for
  normalization purposes. Defaults to "F800.Median".}

  \item{badFlags}{numeric, the identifier of spots to be
  omitted in the signal computation. Defaults to -100.}
}
\value{
  data.frame with columns "index" (numeric, the block
  number), "cab" (factor, the capture antibody names),
  "signal" (numeric, the signal values), "lysate" (numeric,
  0, needs to be set by the slide description, see
  \code{makeArray}), "condition" (numeric, 0, needs to be
  set by the slide description, see \code{makeArray}),
  "error" (numeric, the standard error of the signal
  values)
}
\description{
  \code{getSignals} extracts the signals per block for each
  target
}
\details{
  Signals from different spots (encoded in the \code{Row}
  and \code{Column} columns of \code{signalData}) are
  averaged by computing the arithmetic mean. The error of
  the signal is the standard error, i.e. the standard
  deviation divided by the square root of the number of
  replica.
}

